==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/NodeConditionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class NodeConditionFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConditionFluent<A>{
  public NodeConditionFluentImpl() {
  }
  public NodeConditionFluentImpl(io.fabric8.kubernetes.api.model.NodeCondition instance) {
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
  }
  private java.lang.String lastHeartbeatTime;
  private java.lang.String lastTransitionTime;
  private java.lang.String message;
  private java.lang.String reason;
  private java.lang.String status;
  private java.lang.String type;
  public java.lang.String getLastHeartbeatTime() {
    return this.lastHeartbeatTime;
  }
  public A withLastHeartbeatTime(java.lang.String lastHeartbeatTime) {
    this.lastHeartbeatTime=lastHeartbeatTime; return (A) this;
  }
  public java.lang.Boolean hasLastHeartbeatTime() {
    return this.lastHeartbeatTime != null;
  }
  
  /**
   * Method is deprecated. use withLastHeartbeatTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastHeartbeatTime(java.lang.String arg0) {
    return (A)withLastHeartbeatTime(new String(arg0));
  }
  public java.lang.String getLastTransitionTime() {
    return this.lastTransitionTime;
  }
  public A withLastTransitionTime(java.lang.String lastTransitionTime) {
    this.lastTransitionTime=lastTransitionTime; return (A) this;
  }
  public java.lang.Boolean hasLastTransitionTime() {
    return this.lastTransitionTime != null;
  }
  
  /**
   * Method is deprecated. use withLastTransitionTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTransitionTime(java.lang.String arg0) {
    return (A)withLastTransitionTime(new String(arg0));
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public java.lang.String getStatus() {
    return this.status;
  }
  public A withStatus(java.lang.String status) {
    this.status=status; return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  
  /**
   * Method is deprecated. use withStatus instead.
   */
  @java.lang.Deprecated
  public A withNewStatus(java.lang.String arg0) {
    return (A)withStatus(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConditionFluentImpl that = (NodeConditionFluentImpl) o;
    if (lastHeartbeatTime != null ? !lastHeartbeatTime.equals(that.lastHeartbeatTime) :that.lastHeartbeatTime != null) return false;
    if (lastTransitionTime != null ? !lastTransitionTime.equals(that.lastTransitionTime) :that.lastTransitionTime != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lastHeartbeatTime,  lastTransitionTime,  message,  reason,  status,  type,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/NodeConditionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class NodeConditionFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConditionFluent<A>{
  public NodeConditionFluentImpl() {
  }
  public NodeConditionFluentImpl(io.fabric8.kubernetes.api.model.NodeCondition instance) {
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String lastHeartbeatTime;
  private java.lang.String lastTransitionTime;
  private java.lang.String message;
  private java.lang.String reason;
  private java.lang.String status;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLastHeartbeatTime() {
    return this.lastHeartbeatTime;
  }
  public A withLastHeartbeatTime(java.lang.String lastHeartbeatTime) {
    this.lastHeartbeatTime=lastHeartbeatTime; return (A) this;
  }
  public java.lang.Boolean hasLastHeartbeatTime() {
    return this.lastHeartbeatTime != null;
  }
  
  /**
   * Method is deprecated. use withLastHeartbeatTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastHeartbeatTime(java.lang.String arg0) {
    return (A)withLastHeartbeatTime(new String(arg0));
  }
  public java.lang.String getLastTransitionTime() {
    return this.lastTransitionTime;
  }
  public A withLastTransitionTime(java.lang.String lastTransitionTime) {
    this.lastTransitionTime=lastTransitionTime; return (A) this;
  }
  public java.lang.Boolean hasLastTransitionTime() {
    return this.lastTransitionTime != null;
  }
  
  /**
   * Method is deprecated. use withLastTransitionTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTransitionTime(java.lang.String arg0) {
    return (A)withLastTransitionTime(new String(arg0));
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public java.lang.String getStatus() {
    return this.status;
  }
  public A withStatus(java.lang.String status) {
    this.status=status; return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  
  /**
   * Method is deprecated. use withStatus instead.
   */
  @java.lang.Deprecated
  public A withNewStatus(java.lang.String arg0) {
    return (A)withStatus(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConditionFluentImpl that = (NodeConditionFluentImpl) o;
    if (lastHeartbeatTime != null ? !lastHeartbeatTime.equals(that.lastHeartbeatTime) :that.lastHeartbeatTime != null) return false;
    if (lastTransitionTime != null ? !lastTransitionTime.equals(that.lastTransitionTime) :that.lastTransitionTime != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lastHeartbeatTime,  lastTransitionTime,  message,  reason,  status,  type,  additionalProperties,  super.hashCode());
  }
  
}
